@@ -1,4 +1,4 @@
-from .bookmarks import get_bookmarks
+from .bookmarks import get_bookmarks_list
 from rich.panel import Panel
 from textual.app import App
 from textual.reactive import Reactive
@@ -10,7 +10,7 @@ class Hover(Widget):
     mouse_over = Reactive(False)
 
     def render(self) -> Panel:
-        bookmarks = get_bookmarks()
+        bookmarks = get_bookmarks_list()
         bookmark_list = len(bookmarks)
         bookmark = bookmarks[random.randint(0, bookmark_list-1)]
         link = bookmark.link.split("?utm_source")[0].strip()
@@ -26,7 +26,7 @@ class Hover(Widget):
 class HoverApp(App):
 
     async def on_mount(self) -> None:
-        bookmarks_list = len(get_bookmarks())
+        bookmarks_list = len(get_bookmarks_list())
         hovers = (Hover() for _ in range(5))
         await self.view.dock(*hovers, edge="top")
 
